@@ -10,6 +10,7 @@ TEMPLATE_BUCKET = "ph-platform"
 DAGS_S3_BUCKET = 's3fs-ph-airflow'
 DAGS_S3_PREV_PATH = 'airflow/dags/'
 DAGS_S3_PHJOBS_PATH = '/jobs/python/phcli/'
+DAGS_S3_LMD_PTAH = '/jobs/python/phcli/args_lmd/'
 
 ENV_WORKSPACE_KEY = 'PH_WORKSPACE'
 ENV_WORKSPACE_DEFAULT = '.'
@@ -31,7 +32,13 @@ TEMPLATE_JUPYTER_R_FILE = '/template/python/phcli/maxauto/phJupyterR-20210122.js
 
 TEMPLATE_PHDAG_FILE = "/template/python/phcli/maxauto/phdag-20210104.yaml"
 TEMPLATE_PHGRAPHTEMP_FILE = "/template/python/phcli/maxauto/phgraphtemp-20210104.tmp"
-TEMPLATE_PHDAGJOB_FILE = "/template/python/phcli/maxauto/phDagJob-20210701.tmp"
+TEMPLATE_PHDAGJOB_FILE = "/template/python/phcli/maxauto/phDagJob-20210811.tmp"
+TEMPLATE_SFN_LMD_STEP_FILE = "/template/python/phcli/step_functions/step_tmp/ph-sfn-create-lmd-step-20210713.tmp"
+TEMPLATE_SFN_STEP_FILE = "/template/python/phcli/step_functions/step_tmp/ph-sfn-create-step-20210713.tmp"
+TEMPLATE_SFN_RUN_ID_STEP_FILE = "/template/python/phcli/step_functions/step_tmp/ph-sfn-create-run-id-20210716.tmp"
+TEMPLATE_SFN_DAG_ARGS_STEP_FILE = "/template/python/phcli/step_functions/step_tmp/ph-sfn-create-dag-args-step-20210716.tmp"
+TEMPLATE_SFN_PARALLEL_STEP_FILE = "/template/python/phcli/step_functions/step_tmp/ph-sfn-create-paraller-step-20210708.tmp"
+
 
 DEFAULT_RESULT_PATH_FORMAT_STR = "s3://{bucket_name}/{version}/{dag_name}/"
 DEFAULT_RESULT_PATH_BUCKET = "ph-max-auto"
